@@ -149,7 +149,9 @@ class DataclassSerializer(rest_framework.serializers.Serializer, Generic[T]):
             "inspect 'serializer.validated_data' instead. "
         )
 
-        validated_data = dataclasses.replace(self.validated_data, **kwargs)
+        # Explicitly use internal validated_data here, as we want the empty sentinel values instead of the normalized
+        # external representation.
+        validated_data = dataclasses.replace(self._validated_data, **kwargs)
 
         if self.instance is not None:
             self.instance = self.update(self.instance, validated_data)
@@ -402,7 +404,7 @@ class DataclassSerializer(rest_framework.serializers.Serializer, Generic[T]):
         """
         Create fields for models.
         """
-        relation_info = field_utils.get_relation_info(self.dataclass_definition, type_info)
+        relation_info = field_utils.get_relation_info(type_info)
         field_class = self.serializer_related_field
         field_kwargs = get_relation_kwargs(field_name, relation_info)
 
@@ -530,6 +532,11 @@ class DataclassSerializer(rest_framework.serializers.Serializer, Generic[T]):
 
         return instance
 
+    @cached_property
+    def validated_data(self):
+        internal_validated_data = super(DataclassSerializer, self).validated_data
+        return self._strip_empty_sentinels(internal_validated_data)
+
 
 class HyperlinkedDataclassSerializer(DataclassSerializer):
     serializer_related_field = HyperlinkedRelatedField
